@@ -16,8 +16,6 @@ class AbstractSleepFunctionTest extends TestCase
 {
     /**
      * Tests incrementation of all Incrementables
-     *
-     * @test
      */
     public function testSleepIncrementationOfAllIncrementables()
     {
@@ -37,8 +35,6 @@ class AbstractSleepFunctionTest extends TestCase
      * @param AbstractSleepFunction $sleepFunction Tested implementation.
      * @param int $amount                          Amount of time units.
      * @param mixed $expected                      Expected seconds.
-     *
-     * @test
      * @dataProvider provideTestSleepIncrementation
      */
     public function testSleepIncrementation(
@@ -57,7 +53,7 @@ class AbstractSleepFunctionTest extends TestCase
      *
      * @return array Test cases.
      */
-    public function provideTestSleepIncrementation()
+    public static function provideTestSleepIncrementation()
     {
         return [
             [new SleepFunction(), 1, 1],
