@@ -21,8 +21,6 @@ class IncrementableTest extends TestCase
      * @param mixed $increment              The amount of increase.
      * @param Incrementable $incrementable  The tested Incrementable.
      * @param callable $getValue            The lambda for getting the value.
-     *
-     * @test
      * @dataProvider provideTestIncrement
      */
     public function testIncrement(
@@ -40,7 +38,7 @@ class IncrementableTest extends TestCase
      *
      * @return array Test cases.
      */
-    public function provideTestIncrement()
+    public static function provideTestIncrement()
     {
         $getFixedValue = function (FixedValueFunction $function) {
             return call_user_func($function->getCallable());
