@@ -19,8 +19,6 @@ class MicrotimeConverterTest extends TestCase
      *
      * @param float  $float   The timestamp.
      * @param string $string  The timestamp.
-     *
-     * @test
      * @dataProvider provideFloatAndStrings
      */
     public function testConvertStringToFloat($float, $string)
@@ -34,8 +32,6 @@ class MicrotimeConverterTest extends TestCase
      *
      * @param float  $float   The timestamp.
      * @param string $string  The timestamp.
-     *
-     * @test
      * @dataProvider provideFloatAndStrings
      */
     public function testConvertFloatToString($float, $string)
@@ -49,7 +45,7 @@ class MicrotimeConverterTest extends TestCase
      *
      * @return array
      */
-    public function provideFloatAndStrings()
+    public static function provideFloatAndStrings()
     {
         return [
             [1.0,        "0.00000000 1"],
