@@ -19,8 +19,6 @@ class MockFunctionGeneratorTest extends TestCase
      *
      * @param array $expected  The expected result.
      * @param array $arguments The input arguments.
-     *
-     * @test
      * @dataProvider provideTestRemoveDefaultArguments
      */
     public function testRemoveDefaultArguments(array $expected, array $arguments)
@@ -34,7 +32,7 @@ class MockFunctionGeneratorTest extends TestCase
      *
      * @return The test cases.
      */
-    public function provideTestRemoveDefaultArguments()
+    public static function provideTestRemoveDefaultArguments()
     {
         return[
             [[], []],
