@@ -22,7 +22,6 @@ class ParameterBuilderTest extends TestCase
      * @param string $function          The function name.
      *
      * @dataProvider provideTestBuild
-     * @test
      */
     public function testBuild($expectedSignature, $expectedBody, $function)
     {
@@ -37,7 +36,7 @@ class ParameterBuilderTest extends TestCase
      *
      * @return string[][][] The test cases.
      */
-    public function provideTestBuild()
+    public static function provideTestBuild()
     {
         // @codingStandardsIgnoreStart
 
@@ -84,7 +83,7 @@ class ParameterBuilderTest extends TestCase
         function testCombined($one, &$two, $three = 3, &$four = 4)
         {
         }
-        
+
         function testPHPVariadics1(...$one)
         {
         }
@@ -113,7 +112,7 @@ class ParameterBuilderTest extends TestCase
                }'
           );
         }
-        
+
         // @codingStandardsIgnoreEnd
 
         // PHP8.0+ has a different signature wording.
