@@ -3,7 +3,7 @@
 namespace phpmock\spy;
 
 use phpmock\Mock;
-use phpmock\AbstractMockTest;
+use phpmock\AbstractMockTestCase;
 
 /**
  * Tests the Spy.
@@ -13,7 +13,7 @@ use phpmock\AbstractMockTest;
  * @license http://www.wtfpl.net/txt/copying/ WTFPL
  * @see Spy
  */
-class SpyTest extends AbstractMockTest
+class SpyTest extends AbstractMockTestCase
 {
     protected function defineFunction($namespace, $functionName)
     {
@@ -39,8 +39,6 @@ class SpyTest extends AbstractMockTest
      * @param array    $expected
      * @param string   $name
      * @param callable $invocations
-     *
-     * @test
      * @dataProvider provideTestGetInvocations
      */
     public function testGetInvocations(array $expected, $name, callable $invocations)
@@ -56,7 +54,7 @@ class SpyTest extends AbstractMockTest
      *
      * @return array Test cases for testGetInvocations.
      */
-    public function provideTestGetInvocations()
+    public static function provideTestGetInvocations()
     {
         eval("function testGetInvocations_noParameters() { return 123; }");
         eval("function testGetInvocations_oneParameter(\$a) { return \$a + 1; }");
@@ -121,8 +119,6 @@ class SpyTest extends AbstractMockTest
 
     /**
      * Tests the default function.
-     *
-     * @test
      */
     public function testDefaultFunction()
     {
@@ -136,8 +132,6 @@ class SpyTest extends AbstractMockTest
 
     /**
      * An exception should still be recorded.
-     *
-     * @test
      */
     public function testException()
     {
@@ -160,8 +154,6 @@ class SpyTest extends AbstractMockTest
 
     /**
      * Test the invocation of a none exception call.
-     *
-     * @test
      */
     public function testNoException()
     {
